<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ca">
<context>
    <name>CountdownTooltip</name>
    <message>
        <source>Click the tray icon 
or press the shortcut again to stop recording</source>
        <translation>Feu clic a la icona de la safata
o premeu la drecera de nou per aturar la gravació.</translation>
    </message>
    <message>
        <source>Do not rotate your screen during recording</source>
        <translation>No gireu la pantalla durant la gravació.</translation>
    </message>
</context>
<context>
    <name>IconWidget</name>
    <message>
        <source>Screenshot</source>
        <translation>Captura de pantalla</translation>
    </message>
    <message>
        <source>Recording</source>
        <translation>Gavació</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Screen Capture</source>
        <translation>Captura de pantalla</translation>
    </message>
    <message>
        <source>Save failed. Please save it in your home directory.</source>
        <translation>No s&apos;ha pogut desar. Deseu-ho al directori personal.</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Vista</translation>
    </message>
    <message>
        <source>Screenshot finished</source>
        <translation>Captura acabada</translation>
    </message>
    <message>
        <source>PNG (*.png);;JPEG (*.jpg *.jpeg);;BMP (*.bmp)</source>
        <translation>PNG (*.png);;JPEG (*.jpg *.jpeg);;BMP (*.bmp)</translation>
    </message>
    <message>
        <source>JPEG (*.jpg *.jpeg);;PNG (*.png);;BMP (*.bmp)</source>
        <translation>JPEG (*.jpg *.jpeg);;PNG (*.png);;BMP (*.bmp)</translation>
    </message>
    <message>
        <source>BMP (*.bmp);;JPEG (*.jpg *.jpeg);;PNG (*.png)</source>
        <translation>BMP (*.bmp);;JPEG (*.jpg *.jpeg);;PNG (*.png)</translation>
    </message>
    <message>
        <source>select-area</source>
        <translation>Seleccioneu l&apos;àrea</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Desa</translation>
    </message>
    <message>
        <source>Saved to %1</source>
        <translation>S&apos;ha desat a %1</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>Ignora</translation>
    </message>
    <message>
        <source>Clipboard</source>
        <translation>Porta-retalls</translation>
    </message>
    <message>
        <source>Saving the screen recording file, please wait...</source>
        <translation>Es desa el fitxer de gravació de pantalla. Espereu, si us plau...</translation>
    </message>
    <message>
        <source>As the window effect is disabled during the process, the recording has to be stopped</source>
        <translation>Com que l’efecte de finestra es desactiva durant el procés, s’ha d’aturar la gravació.</translation>
    </message>
    <message>
        <source>Screenshot</source>
        <translation>Captura de pantalla</translation>
    </message>
    <message>
        <source>Scrollshot</source>
        <translation>Captura de desplaçament</translation>
    </message>
    <message>
        <source>Pin Screenshots</source>
        <translation>Fixa les captures</translation>
    </message>
    <message>
        <source>deepin-screen-recorder</source>
        <translation>deepin-screen-recorder</translation>
    </message>
    <message>
        <source>Open Folder</source>
        <translation>Obre la carpeta</translation>
    </message>
    <message>
        <source>Screenshot finished and copy to clipboard</source>
        <translation>Captura finalitzada i copiada al portapapeles</translation>
    </message>
</context>
<context>
    <name>MenuController</name>
    <message>
        <source>Undo</source>
        <translation>Desfés</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Desa</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Surt</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Pin Screenshots</source>
        <translation>Fixa les captures</translation>
    </message>
</context>
<context>
    <name>QuickPanelWidget</name>
    <message>
        <source>Screenshot</source>
        <translation>Captura de pantalla</translation>
    </message>
    <message>
        <source>Record</source>
        <translation>Grava</translation>
    </message>
</context>
<context>
    <name>RecordIconWidget</name>
    <message>
        <source>Screenshot</source>
        <translation>Captura de pantalla</translation>
    </message>
    <message>
        <source>Recording</source>
        <translation>Gavació</translation>
    </message>
</context>
<context>
    <name>RecordProcess</name>
    <message>
        <source>View</source>
        <translation>Vista</translation>
    </message>
    <message>
        <source>Recording finished</source>
        <translation>Gravació acabada</translation>
    </message>
    <message>
        <source>Saved to %1</source>
        <translation>S&apos;ha desat a %1</translation>
    </message>
    <message>
        <source>Record</source>
        <translation>Grava</translation>
    </message>
    <message>
        <source>Open Folder</source>
        <translation>Obre la carpeta</translation>
    </message>
</context>
<context>
    <name>Screenshot</name>
    <message>
        <source>Screen Capture will start in %1 seconds</source>
        <translation>La Captura de pantalla s&apos;iniciarà d&apos;aquí a %1 segons</translation>
    </message>
</context>
<context>
    <name>ScrollShotTip</name>
    <message>
        <source>Get help.</source>
        <translation>Obteniu ajuda</translation>
    </message>
    <message>
        <source>Failed to take a continuous screenshot.</source>
        <translation>Ha fallat fer una captura de pantalla contínua.</translation>
    </message>
    <message>
        <source>Reached the bottom of the scroll area</source>
        <translation>S&apos;ha arribat al capdavall de l&apos;àrea de desplaçament.</translation>
    </message>
    <message>
        <source>Reached the maximum length</source>
        <translation>S&apos;ha arribat a l&apos;extensió màxima.</translation>
    </message>
    <message>
        <source>adjust the capture area</source>
        <translation>ajustar l&apos;àrea de captura</translation>
    </message>
    <message>
        <source>Scroll your mouse wheel or click to take a scrolling screenshot</source>
        <translation>Feu girar la roda del ratolí o cliqueu per fer una captura de pantalla de desplaçament.</translation>
    </message>
    <message>
        <source>Slow down the scrolling speed</source>
        <translation>Reduïu la velocitat del desplaçament.</translation>
    </message>
    <message>
        <source>Invalid area, click to </source>
        <translation>Àrea no vàlida, cliqueu per</translation>
    </message>
</context>
<context>
    <name>ShapesWidget</name>
    <message>
        <source>Input text here</source>
        <translation>Introduïu el text aquí</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Start/Screenshot</source>
        <translation>Inicia/Captura de pantalla</translation>
    </message>
    <message>
        <source>Exit/Save</source>
        <translation>Surt/Desa</translation>
    </message>
    <message>
        <source>Size Adjustment</source>
        <translation>Ajust de la mida</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Configuració</translation>
    </message>
    <message>
        <source>Quick start</source>
        <translation>Inici ràpid</translation>
    </message>
    <message>
        <source>Window screenshot</source>
        <translation>Captura la finestra</translation>
    </message>
    <message>
        <source>Delay screenshot</source>
        <translation>Captura de pantalla amb retard</translation>
    </message>
    <message>
        <source>Full screenshot</source>
        <translation>Captura de pantalla completa</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Surt</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Desa</translation>
    </message>
    <message>
        <source>Rectangle</source>
        <translation>Rectangle</translation>
    </message>
    <message>
        <source>Ellipse</source>
        <translation>El·lipse</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>Línia</translation>
    </message>
    <message>
        <source>Pencil</source>
        <translation>Llapis</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>Text</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Suprimeix</translation>
    </message>
    <message>
        <source>Undo</source>
        <translation>Desfés</translation>
    </message>
    <message>
        <source>Increase height up</source>
        <translation>Augmenta l&apos;alçada cap amunt</translation>
    </message>
    <message>
        <source>Increase height down</source>
        <translation>Augmenta l&apos;alçada cap avall</translation>
    </message>
    <message>
        <source>Increase width left</source>
        <translation>Augmenta l&apos;amplada a l&apos;esquerra</translation>
    </message>
    <message>
        <source>Increase width right</source>
        <translation>Augmenta l&apos;amplada a la dreta</translation>
    </message>
    <message>
        <source>Decrease height up</source>
        <translation>Disminueix l&apos;alçada cap amunt</translation>
    </message>
    <message>
        <source>Decrease height down</source>
        <translation>Disminueix l&apos;alçada cap avall</translation>
    </message>
    <message>
        <source>Decrease width left</source>
        <translation>Disminueix l&apos;amplada a l&apos;esquerra</translation>
    </message>
    <message>
        <source>Decrease width right</source>
        <translation>Disminueix l&apos;amplada a la dreta</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Ajuda</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Mostra les dreceres</translation>
    </message>
    <message>
        <source>Sound</source>
        <translation>So</translation>
    </message>
    <message>
        <source>Keystroke</source>
        <translation>Pulsació</translation>
    </message>
    <message>
        <source>Webcam</source>
        <translation>Càmera web</translation>
    </message>
    <message>
        <source>Start recording</source>
        <translation>Inicia la gravació</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Opcions</translation>
    </message>
    <message>
        <source>Start/Recording</source>
        <translation>Inici / gravació</translation>
    </message>
    <message>
        <source>Mouse</source>
        <translation>Ratolí</translation>
    </message>
    <message>
        <source>Tools</source>
        <translation>Eines</translation>
    </message>
    <message>
        <source>Extract text</source>
        <translation>Extreu-ne el text</translation>
    </message>
    <message>
        <source>Scrollshot</source>
        <translation>Captura de desplaçament</translation>
    </message>
    <message>
        <source>Pin screenshots</source>
        <translation>Fixa les captures</translation>
    </message>
    <message>
        <source>Start OCR</source>
        <translation>Inicia el ROC</translation>
    </message>
    <message>
        <source>Start scrollshot</source>
        <translation>Inicia la captura de desplaçament</translation>
    </message>
    <message>
        <source>Arrow</source>
        <translation>Fletxa</translation>
    </message>
</context>
<context>
    <name>ShotStartPlugin</name>
    <message>
        <source>Screenshot</source>
        <translation>Captura de pantalla</translation>
    </message>
</context>
<context>
    <name>ShotStartRecordPlugin</name>
    <message>
        <source>Record</source>
        <translation>Grava</translation>
    </message>
</context>
<context>
    <name>ShotToolWidget</name>
    <message>
        <source>Rectangle
Press and hold Shift to draw a square</source>
        <translation>Rectangle
Manteniu premuda la tecla Maj per dibuixar un quadrat.</translation>
    </message>
    <message>
        <source>Ellipse
Press and hold Shift to draw a circle</source>
        <translation>El·lipse
Manteniu premuda la tecla Maj per dibuixar un cercle.</translation>
    </message>
    <message>
        <source>Brush
Press and hold Shift to draw a straight line</source>
        <translation>Pinzell
Manteniu premuda la tecla Maj per dibuixar una línia recta.</translation>
    </message>
    <message>
        <source>Adjust blur strength (Scroll to adjust it)</source>
        <translation>Ajusta la força del desenfocament (desplaçament per ajustar-lo)</translation>
    </message>
    <message>
        <source>Adjust brush size (Scroll to adjust it)</source>
        <translation>Ajusta la mida del pinzell (desplaçament per ajustar-lo)</translation>
    </message>
    <message>
        <source>Adjust text size (Scroll to adjust it)</source>
        <translation>Ajusta la mida del text (desplaçament per ajustar-lo)</translation>
    </message>
</context>
<context>
    <name>SubToolWidget</name>
    <message>
        <source>Show keystroke (K)</source>
        <translation>Mostra la pulsació de la tecla (K)</translation>
    </message>
    <message>
        <source>Hide Keystroke (K)</source>
        <translation>Amaga la pulsació de tecles (K)</translation>
    </message>
    <message>
        <source>Show Keystroke (K)</source>
        <translation>Mostra la pulsació de tecles (K)</translation>
    </message>
    <message>
        <source>Turn on camera (C)</source>
        <translation>Activa la càmera (C)</translation>
    </message>
    <message>
        <source>Turn off camera (C)</source>
        <translation>Apaga la càmera (C)</translation>
    </message>
    <message>
        <source>Screenshot</source>
        <translation>Captura de pantalla</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Configuració</translation>
    </message>
    <message>
        <source>Settings (F3)</source>
        <translation>Configuració (F3)</translation>
    </message>
    <message>
        <source>Format:</source>
        <translation>Format:</translation>
    </message>
    <message>
        <source>GIF</source>
        <translation>GIF</translation>
    </message>
    <message>
        <source>MP4</source>
        <translation>MP4</translation>
    </message>
    <message>
        <source>MKV</source>
        <translation>MKV</translation>
    </message>
    <message>
        <source>webm</source>
        <translation>webm</translation>
    </message>
    <message>
        <source>FPS:</source>
        <translation>FPS:</translation>
    </message>
    <message>
        <source>5 fps</source>
        <translation>5 fps</translation>
    </message>
    <message>
        <source>10 fps</source>
        <translation>10 fps</translation>
    </message>
    <message>
        <source>20 fps</source>
        <translation>20 fps</translation>
    </message>
    <message>
        <source>24 fps</source>
        <translation>24 fps</translation>
    </message>
    <message>
        <source>30 fps</source>
        <translation>30 fps</translation>
    </message>
    <message>
        <source>Sound</source>
        <translation>So</translation>
    </message>
    <message>
        <source>Microphone</source>
        <translation>Micròfon</translation>
    </message>
    <message>
        <source>System audio</source>
        <translation>Àudio del sistema</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Opcions</translation>
    </message>
    <message>
        <source>Show pointer</source>
        <translation>Mostra el punter</translation>
    </message>
    <message>
        <source>Show click</source>
        <translation>Mostra els clics</translation>
    </message>
    <message>
        <source>Save to</source>
        <translation>Desa a</translation>
    </message>
    <message>
        <source>Desktop</source>
        <translation>Escriptori</translation>
    </message>
    <message>
        <source>Videos</source>
        <translation>Vídeos</translation>
    </message>
    <message>
        <source>Line (L)
Press and hold Shift to draw a vertical or horizontal line</source>
        <translation>Línia (L)
Manteniu premuda la tecla Maj per dibuixar una línia vertical o horitzontal.</translation>
    </message>
    <message>
        <source>Arrow (X)
Press and hold Shift to draw a vertical or horizontal arrow</source>
        <translation>Fletxa (X)
Manteniu premuda la tecla Maj per dibuixar una fletxa vertical o horitzontal.</translation>
    </message>
    <message>
        <source>Pencil (P)</source>
        <translation>Llapis (P)</translation>
    </message>
    <message>
        <source>Blur (B)</source>
        <translation>Desenfocament (B)</translation>
    </message>
    <message>
        <source>Text (T)</source>
        <translation>Text (T)</translation>
    </message>
    <message>
        <source>Scrollshot (Alt+I）</source>
        <translation>Captura de desplaçament (Alt+I)</translation>
    </message>
    <message>
        <source>Extract text (Alt+O）</source>
        <translation>Extreu text (Alt+O)</translation>
    </message>
    <message>
        <source>Pin screenshots (Alt+P）</source>
        <translation>Fixa les captures de pantalla (Alt+P)</translation>
    </message>
    <message>
        <source>Undo (Ctrl+Z)</source>
        <translation>Desfés (Ctrl+Z)</translation>
    </message>
    <message>
        <source>Record</source>
        <translation>Grava</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>Fotos</translation>
    </message>
    <message>
        <source>Set a path on save</source>
        <translation>Estableix un camí per desar</translation>
    </message>
    <message>
        <source>Change the path on save</source>
        <translation>Canvia el camí per desar</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>Format</translation>
    </message>
    <message>
        <source>PNG</source>
        <translation>PNG</translation>
    </message>
    <message>
        <source>JPG</source>
        <translation>JPG</translation>
    </message>
    <message>
        <source>BMP</source>
        <translation>BMP</translation>
    </message>
    <message>
        <source>Border Effects</source>
        <translation>Efectes de la vora</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Cap</translation>
    </message>
    <message>
        <source>Shadow</source>
        <translation>Ombra</translation>
    </message>
    <message>
        <source>Border</source>
        <translation>Vora</translation>
    </message>
    <message>
        <source>Device</source>
        <translation>Dispositiu</translation>
    </message>
    <message>
        <source>Extract Text</source>
        <translation>Extreu-ne el text</translation>
    </message>
    <message>
        <source>Geometric Tools (R)
Hold down Shift to draw squares or circles.</source>
        <translation>Manteniu premuda la tecla Maj per dibuixar quadrats o cercles.</translation>
    </message>
    <message>
        <source>Save to local</source>
        <translation>Desa a local</translation>
    </message>
    <message>
        <source>Save to Desktop</source>
        <translation>Desa a l&apos;escriptori</translation>
    </message>
    <message>
        <source>Save to Pictures</source>
        <translation>Desa a fotos</translation>
    </message>
    <message>
        <source>Save to %1</source>
        <translation>Desa a %1</translation>
    </message>
    <message>
        <source>Specified Location</source>
        <translation>Ubicació especificada</translation>
    </message>
    <message>
        <source>Custom Location</source>
        <translation>Ubicació personalitzada</translation>
    </message>
    <message>
        <source>Each inquiry</source>
        <translation>Cada pregunta</translation>
    </message>
    <message>
        <source>Update location on save</source>
        <translation>Actualitza la ubicació al desar</translation>
    </message>
    <message>
        <source>Save to desktop</source>
        <translation>Desa a l&apos;escriptori</translation>
    </message>
    <message>
        <source>Save to pictures</source>
        <translation>Desa a fotos</translation>
    </message>
</context>
<context>
    <name>ToolBarWidget</name>
    <message>
        <source>Close (Esc)</source>
        <translation>Tanca (Esc)</translation>
    </message>
    <message>
        <source>Copy to clipboard (Enter)</source>
        <translation>Copia a la porta-retalls (Enter)</translation>
    </message>
</context>
<context>
    <name>TopTips</name>
    <message>
        <source> Adjust the recording area within %1*%2 to get better video effect</source>
        <translation> Ajusteu l&apos;àrea de gravació dins %1*%2 per obtenir un efecte de vídeo millor.</translation>
    </message>
</context>
<context>
    <name>Utils</name>
    <message>
        <source>Screen recording is not supported at present</source>
        <translation>Actualment no s&apos;admet la gravació de pantalla</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Surt</translation>
    </message>
</context>
</TS>
